@@ -6,14 +6,14 @@ import enum
 import typing as t
 import inspect
 
-from typing_extensions import Final, TypedDict
-
 import cg_maybe
 
 from ._base import Parser, SimpleValue
 from ._enum import StringEnum
 from ._utils import USE_SLOTS as _USE_SLOTS
 from ._utils import T as _T
+from ._utils import Y as _Y
+from ._utils import Final, TypedDict
 from .exceptions import ParseError, SimpleParseError, MultipleParseErrors
 from ._swagger_utils import OpenAPISchema
 
@@ -535,6 +535,39 @@ class DiscriminatedUnion(t.Generic[_T], Parser[_T]):
         self.__parser_lookup = parser_lookup
         self.__key_parser = StringEnum(*parser_lookup.keys())  # type: ignore
 
+    def maybe_merge(
+        self, other: 'DiscriminatedUnion[_Y]'
+    ) -> cg_maybe.Maybe['DiscriminatedUnion[t.Union[_T, _Y]]']:
+        """Try to merge two discriminated unions.
+
+        :param other: The other discriminated union to add.
+
+        :returns: A new discriminated union, if it could be created.
+        """
+        parsers: t.Sequence[Parser[t.Union[_T, _Y]]] = (
+            *self.__parser_lookup.values(),
+            *other.__parser_lookup.values(),  # pylint: disable=protected-access
+        )
+        return DiscriminatedUnion.maybe_create(parsers)
+
+    def maybe_add(
+        self,
+        parser: Parser[_Y],
+    ) -> cg_maybe.Maybe['DiscriminatedUnion[t.Union[_T, _Y]]']:
+        """Maybe add a parser to this discriminated union.
+
+        :param parser: The parser to add.
+
+        :returns: A new discriminated union, if it could be created.
+        """
+        maybe_other: cg_maybe.Maybe[DiscriminatedUnion[_Y]]
+        if isinstance(parser, DiscriminatedUnion):
+            maybe_other = cg_maybe.Just(parser)
+        else:
+            maybe_other = DiscriminatedUnion.maybe_create((parser, ))
+
+        return maybe_other.chain(self.maybe_merge)
+
     @classmethod
     def maybe_create(
         cls, parsers: t.Sequence[Parser[_T]]
@@ -618,7 +651,11 @@ class DiscriminatedUnion(t.Generic[_T], Parser[_T]):
         for name, parser in self.__parser_lookup.items():
             sub = parser.to_open_api(schema)
             if '$ref' not in sub:
-                assert 'x-model-name' in sub
+                if 'x-model-name' not in sub:  # pragma: no cover
+                    raise AssertionError((
+                        f'Expected to find x-model-name in {sub} but did not'
+                        f' find it.'
+                    ))
                 sub = schema.add_as_schema(sub['x-model-name'], sub, parser)
             mapping[name] = sub['$ref']
         return {
