@@ -2,6 +2,7 @@
 
 SPDX-License-Identifier: AGPL-3.0-only OR BSD-3-Clause-Clear
 """
+
 import datetime
 import typing as t
 from dataclasses import dataclass, field
@@ -312,6 +313,9 @@ class AllSiteSettings(FrontendSiteSettings):
             "PEER_FEEDBACK_ENABLED": to_dict(self.peer_feedback_enabled),
             "AT_IMAGE_CACHING_ENABLED": to_dict(self.at_image_caching_enabled),
             "STUDENT_PAYMENT_ENABLED": to_dict(self.student_payment_enabled),
+            "FEEDBACK_THREADS_INITIALLY_COLLAPSED": to_dict(
+                self.feedback_threads_initially_collapsed
+            ),
         }
         return res
 
@@ -371,6 +375,15 @@ class AllSiteSettings(FrontendSiteSettings):
             peer_feedback_enabled=parsed.PEER_FEEDBACK_ENABLED,
             at_image_caching_enabled=parsed.AT_IMAGE_CACHING_ENABLED,
             student_payment_enabled=parsed.STUDENT_PAYMENT_ENABLED,
+            feedback_threads_initially_collapsed=parsed.FEEDBACK_THREADS_INITIALLY_COLLAPSED,
         )
         res.raw_data = d
         return res
+
+
+import os
+
+if os.getenv("CG_GENERATING_DOCS", "False").lower() in ("", "true"):
+    # fmt: off
+    pass
+    # fmt: on
