@@ -2,6 +2,7 @@
 
 SPDX-License-Identifier: AGPL-3.0-only OR BSD-3-Clause-Clear
 """
+
 import typing as t
 from dataclasses import dataclass, field
 
@@ -158,19 +159,20 @@ class CoursePermMap:
     #: Users with this permission can see the output of linters before an
     #: assignment is set to "done"
     can_see_linter_feedback_before_done: "bool"
-    #: Users with this permission can see all feedback, except for peer
-    #: feedback, before an assignment is set to "done"
+    #: Users with this permission can see all inline and general feedback,
+    #: except for peer feedback, before an assignment is set to "done"
     can_see_user_feedback_before_done: "bool"
     #: Users with this permission can view the analytics dashboard of an
     #: assignment.
     can_view_analytics: "bool"
-    #: Users with this permission can edit inline comments left by other users
+    #: Users with this permission can edit inline and general comments left by
+    #: other users
     can_edit_others_comments: "bool"
-    #: Users with this permission can add and reply to inline comments on
-    #: submissions they are the author of
+    #: Users with this permission can add and reply to inline and general
+    #: comments on submissions they are the author of
     can_add_own_inline_comments: "bool"
-    #: Users with this permission may see the edit history of comments placed
-    #: by others
+    #: Users with this permission may see the edit history of inline and
+    #: general comments placed by others
     can_view_others_comment_edits: "bool"
     #: Users with this permission can view the author of inline and general
     #: feedback
@@ -178,13 +180,13 @@ class CoursePermMap:
     #: Users with this permission can email students using the contact student
     #: button.
     can_email_students: "bool"
-    #: Users with this permission can view unapproved inline comments, comments
-    #: that need approval include peer feedback comments. Users still need to
-    #: have the permission to see the feedback, so this permission alone is not
-    #: enough to see peer feedback.
+    #: Users with this permission can view unapproved inline and general
+    #: comments, comments that need approval include peer feedback comments.
+    #: Users still need to have the permission to see the feedback, so this
+    #: permission alone is not enough to see peer feedback.
     can_view_inline_feedback_before_approved: "bool"
-    #: Users with this permission can approve inline comments, comments that
-    #: need approval include peer feedback comments.
+    #: Users with this permission can approve inline and general comments,
+    #: comments that need approval include peer feedback comments.
     can_approve_inline_comments: "bool"
     #: Users with this permission can edit the peer feedback status of an
     #: assignment.
@@ -207,12 +209,15 @@ class CoursePermMap:
     #: Users with this permission can still upload (submit) work after the lock
     #: date of an assignment.
     can_upload_after_lock_date: "bool"
-    #: Users with this permission are allowed to see peer feedback before the
-    #: state of an assignment has been set to "done".
+    #: Users with this permission are allowed to see inline and general peer
+    #: feedback before the state of an assignment has been set to "done".
     can_see_peer_feedback_before_done: "bool"
     #: Users with this permission can see the real name of students even when
     #: anonymized grading is enabled.
     can_see_anonymized_names: "bool"
+    #: Users with this permission can view AutoTest results of other users they
+    #: are peer reviewing.
+    can_view_peer_review_autotest_results: "bool"
 
     raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)
 
@@ -617,8 +622,9 @@ class CoursePermMap:
                 "can_see_user_feedback_before_done",
                 rqa.SimpleValue.bool,
                 doc=(
-                    "Users with this permission can see all feedback, except"
-                    ' for peer feedback, before an assignment is set to "done"'
+                    "Users with this permission can see all inline and general"
+                    " feedback, except for peer feedback, before an assignment"
+                    ' is set to "done"'
                 ),
             ),
             rqa.RequiredArgument(
@@ -633,8 +639,8 @@ class CoursePermMap:
                 "can_edit_others_comments",
                 rqa.SimpleValue.bool,
                 doc=(
-                    "Users with this permission can edit inline comments left"
-                    " by other users"
+                    "Users with this permission can edit inline and general"
+                    " comments left by other users"
                 ),
             ),
             rqa.RequiredArgument(
@@ -642,7 +648,8 @@ class CoursePermMap:
                 rqa.SimpleValue.bool,
                 doc=(
                     "Users with this permission can add and reply to inline"
-                    " comments on submissions they are the author of"
+                    " and general comments on submissions they are the"
+                    " author of"
                 ),
             ),
             rqa.RequiredArgument(
@@ -650,7 +657,7 @@ class CoursePermMap:
                 rqa.SimpleValue.bool,
                 doc=(
                     "Users with this permission may see the edit history of"
-                    " comments placed by others"
+                    " inline and general comments placed by others"
                 ),
             ),
             rqa.RequiredArgument(
@@ -673,9 +680,9 @@ class CoursePermMap:
                 "can_view_inline_feedback_before_approved",
                 rqa.SimpleValue.bool,
                 doc=(
-                    "Users with this permission can view unapproved inline"
-                    " comments, comments that need approval include peer"
-                    " feedback comments. Users still need to have the"
+                    "Users with this permission can view unapproved inline and"
+                    " general comments, comments that need approval include"
+                    " peer feedback comments. Users still need to have the"
                     " permission to see the feedback, so this permission alone"
                     " is not enough to see peer feedback."
                 ),
@@ -684,9 +691,9 @@ class CoursePermMap:
                 "can_approve_inline_comments",
                 rqa.SimpleValue.bool,
                 doc=(
-                    "Users with this permission can approve inline comments,"
-                    " comments that need approval include peer feedback"
-                    " comments."
+                    "Users with this permission can approve inline and general"
+                    " comments, comments that need approval include peer"
+                    " feedback comments."
                 ),
             ),
             rqa.RequiredArgument(
@@ -746,9 +753,9 @@ class CoursePermMap:
                 "can_see_peer_feedback_before_done",
                 rqa.SimpleValue.bool,
                 doc=(
-                    "Users with this permission are allowed to see peer"
-                    " feedback before the state of an assignment has been set"
-                    ' to "done".'
+                    "Users with this permission are allowed to see inline and"
+                    " general peer feedback before the state of an assignment"
+                    ' has been set to "done".'
                 ),
             ),
             rqa.RequiredArgument(
@@ -759,6 +766,14 @@ class CoursePermMap:
                     " students even when anonymized grading is enabled."
                 ),
             ),
+            rqa.RequiredArgument(
+                "can_view_peer_review_autotest_results",
+                rqa.SimpleValue.bool,
+                doc=(
+                    "Users with this permission can view AutoTest results of"
+                    " other users they are peer reviewing."
+                ),
+            ),
         ).use_readable_describe(True)
     )
 
@@ -875,6 +890,9 @@ class CoursePermMap:
                 self.can_see_peer_feedback_before_done
             ),
             "can_see_anonymized_names": to_dict(self.can_see_anonymized_names),
+            "can_view_peer_review_autotest_results": to_dict(
+                self.can_view_peer_review_autotest_results
+            ),
         }
         return res
 
@@ -950,6 +968,7 @@ class CoursePermMap:
             can_upload_after_lock_date=parsed.can_upload_after_lock_date,
             can_see_peer_feedback_before_done=parsed.can_see_peer_feedback_before_done,
             can_see_anonymized_names=parsed.can_see_anonymized_names,
+            can_view_peer_review_autotest_results=parsed.can_view_peer_review_autotest_results,
         )
         res.raw_data = d
         return res
