@@ -75,3 +75,6 @@ class CoursePermission(str, Enum):
     can_upload_after_lock_date = "can_upload_after_lock_date"
     can_see_peer_feedback_before_done = "can_see_peer_feedback_before_done"
     can_see_anonymized_names = "can_see_anonymized_names"
+    can_view_peer_review_autotest_results = (
+        "can_view_peer_review_autotest_results"
+    )
