@@ -2,6 +2,7 @@
 
 SPDX-License-Identifier: AGPL-3.0-only OR BSD-3-Clause-Clear
 """
+
 import datetime
 import typing as t
 from dataclasses import dataclass, field
@@ -112,6 +113,8 @@ class FrontendSiteSettings:
     #: to enable this deploy config needs to be updated, so don't just enable
     #: it.
     student_payment_enabled: "bool"
+    #: Feedback threads will start collapsed from this depth of the tree.
+    feedback_threads_initially_collapsed: "int"
 
     raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)
 
@@ -363,6 +366,14 @@ class FrontendSiteSettings:
                     " be updated, so don't just enable it."
                 ),
             ),
+            rqa.RequiredArgument(
+                "FEEDBACK_THREADS_INITIALLY_COLLAPSED",
+                rqa.SimpleValue.int,
+                doc=(
+                    "Feedback threads will start collapsed from this depth of"
+                    " the tree."
+                ),
+            ),
         ).use_readable_describe(True)
     )
 
@@ -432,6 +443,9 @@ class FrontendSiteSettings:
             "PEER_FEEDBACK_ENABLED": to_dict(self.peer_feedback_enabled),
             "AT_IMAGE_CACHING_ENABLED": to_dict(self.at_image_caching_enabled),
             "STUDENT_PAYMENT_ENABLED": to_dict(self.student_payment_enabled),
+            "FEEDBACK_THREADS_INITIALLY_COLLAPSED": to_dict(
+                self.feedback_threads_initially_collapsed
+            ),
         }
         return res
 
@@ -476,6 +490,7 @@ class FrontendSiteSettings:
             peer_feedback_enabled=parsed.PEER_FEEDBACK_ENABLED,
             at_image_caching_enabled=parsed.AT_IMAGE_CACHING_ENABLED,
             student_payment_enabled=parsed.STUDENT_PAYMENT_ENABLED,
+            feedback_threads_initially_collapsed=parsed.FEEDBACK_THREADS_INITIALLY_COLLAPSED,
         )
         res.raw_data = d
         return res
