@@ -2,6 +2,7 @@
 
 SPDX-License-Identifier: AGPL-3.0-only OR BSD-3-Clause-Clear
 """
+
 import typing as t
 from dataclasses import dataclass, field
 
@@ -61,6 +62,12 @@ class GlobalPermMap:
     #: Users with this permission are allowed to view all transactions from all
     #: users.
     can_see_all_transactions: "bool"
+    #: Users with this permission can create, edit and delete pricing coupons
+    #: for courses.
+    can_edit_coupons: "bool"
+    #: Users with this permission can see the pricing coupons generated for the
+    #: courses they are part of.
+    can_see_coupons: "bool"
 
     raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)
 
@@ -213,6 +220,22 @@ class GlobalPermMap:
                     " transactions from all users."
                 ),
             ),
+            rqa.RequiredArgument(
+                "can_edit_coupons",
+                rqa.SimpleValue.bool,
+                doc=(
+                    "Users with this permission can create, edit and delete"
+                    " pricing coupons for courses."
+                ),
+            ),
+            rqa.RequiredArgument(
+                "can_see_coupons",
+                rqa.SimpleValue.bool,
+                doc=(
+                    "Users with this permission can see the pricing coupons"
+                    " generated for the courses they are part of."
+                ),
+            ),
         ).use_readable_describe(True)
     )
 
@@ -245,6 +268,8 @@ class GlobalPermMap:
             "can_skip_payment": to_dict(self.can_skip_payment),
             "can_edit_pricing": to_dict(self.can_edit_pricing),
             "can_see_all_transactions": to_dict(self.can_see_all_transactions),
+            "can_edit_coupons": to_dict(self.can_edit_coupons),
+            "can_see_coupons": to_dict(self.can_see_coupons),
         }
         return res
 
@@ -274,6 +299,8 @@ class GlobalPermMap:
             can_skip_payment=parsed.can_skip_payment,
             can_edit_pricing=parsed.can_edit_pricing,
             can_see_all_transactions=parsed.can_see_all_transactions,
+            can_edit_coupons=parsed.can_edit_coupons,
+            can_see_coupons=parsed.can_see_coupons,
         )
         res.raw_data = d
         return res
